Qurro

Loading Qurro plots; this might take a few seconds...
Ranking
Bar width

Warning: The rank plot is currently using a bar width of less than one pixel per bar. This means that the image shown isn't necessarily going to be an accurate representation of the rank plot.

x-axis field
x-axis scale type
Color field
Color scale type
(Experimental) Use boxplots for categorical data?

#### Numerator Features (0 selected)

#### Denominator Features (0 selected)

### Selecting Features

To construct a log ratio, select feature(s) by clicking on the plot of feature ranks on the left or by searching using the controls below.

#### Numerator

Filter to features where

#### Denominator

Filter to features where